@@ -61,18 +61,20 @@ class SurfingEntrance(object):
 
     def init_basic(self):
         from .data.wrapper.mysql import BasicDatabaseConnector
-        from .data.view.basic_models import Base
+        from .data.view.basic_models import Base, FOFBase
 
         print('Begin to create tables for database: basic')
         Base.metadata.create_all(bind=BasicDatabaseConnector().get_engine())
+        FOFBase.metadata.create_all(bind=BasicDatabaseConnector().get_engine())
         print('done')
 
     def init_derived(self):
         from .data.wrapper.mysql import DerivedDatabaseConnector
-        from .data.view.derived_models import Base
+        from .data.view.derived_models import Base, FOFBase
 
         print('Begin to create tables for database: derived')
         Base.metadata.create_all(bind=DerivedDatabaseConnector().get_engine())
+        FOFBase.metadata.create_all(bind=DerivedDatabaseConnector().get_engine())
         print('done')
 
     def init_view(self):
@@ -226,7 +228,7 @@ class SurfingEntrance(object):
         from .data.fund.basic.fund_estimated_nav_processor import FundEstimatedNavProcessor
 
         USE_SINA_DATA = True
-        
+
         fund_estimated_nav_processor = FundEstimatedNavProcessor()
         if not fund_estimated_nav_processor.init():
             return
@@ -250,7 +252,7 @@ class SurfingEntrance(object):
                 time_start_second = time_start.second
                 time_start_str = time_start.strftime('%Y-%m-%d %H:%M')
                 time_start = datetime.datetime.strptime(time_start_str, '%Y-%m-%d %H:%M')
-                
+
                 if time_start.hour < 9 or time_start.hour == 12 or time_start.hour > 15:
                     # Exit when time_start is in range [0:00, 8:59], [12:00, 12:59] and [16:00 23:59]
                     print(f'Current time {time_start} is not trading time. Will exit.')
@@ -300,7 +302,7 @@ class SurfingEntrance(object):
         from .data.fund.raw.raw_data_helper import RawDataHelper
         from .data.fund.raw.em_raw_data_downloader import EmRawDataDownloader
         from .data.fund.basic.realtime_index_price_processor import RealtimeIndexPriceProcessor
-        
+
         realtime_index_price_processor = RealtimeIndexPriceProcessor()
         if not realtime_index_price_processor.init():
             return
@@ -318,7 +320,7 @@ class SurfingEntrance(object):
                 time_start_second = time_start.second
                 time_start_str = time_start.strftime('%Y-%m-%d %H:%M')
                 time_start = datetime.datetime.strptime(time_start_str, '%Y-%m-%d %H:%M')
-                
+
                 if time_start.hour < 9 or time_start.hour == 12 or time_start.hour > 15:
                     # Exit when time_start is in range [0:00, 8:59], [12:00, 12:59] and [16:00 23:59]
                     print(f'Current time {time_start} is not trading time. Will exit.')
@@ -479,13 +481,13 @@ class SurfingEntrance(object):
         if wechat_bot is None:
             from .util.wechat_bot import WechatBot
             wechat_bot = WechatBot()
-        wechat_bot.send_update_stock_factor_result(yesterday, failed_factors)
+        wechat_bot.send_update_factor_result(yesterday, 'stock', failed_factors)
 
     def update_fund_factor(self, yesterday=None, wechat_bot=None):
         import pandas as pd
         from .stock.factor.api import FundFactorUpdater
         from .data.api.basic import BasicDataApi
-        
+
         if yesterday is None:
             yesterday = self._get_yesterday()
 
@@ -505,11 +507,11 @@ class SurfingEntrance(object):
                 return
             else:
                 failed_factors: List[str] = FundFactorUpdater.do_update_every_week()
-            
+
         if wechat_bot is None:
             from .util.wechat_bot import WechatBot
             wechat_bot = WechatBot()
-        wechat_bot.send_update_stock_factor_result(yesterday, failed_factors)
+        wechat_bot.send_update_factor_result(yesterday, 'fund', failed_factors)
 
     def check_refinancing(self, yesterday=None, wechat_bot=None):
         from .data.api.raw import RawDataApi
