@@ -325,4 +325,46 @@ class ExchangeStatus(ReadableEnum):
     OPEN = 0
     SUSPENDED = 1
     LIMITED = 2
-    CLOSE = 3
\ No newline at end of file
+    CLOSE = 3
+
+
+class FOFTradeStatus(ReadableEnum):
+    PURCHASE = 1
+    SUBSCRIBE = 2
+    REDEEM = 3
+    DIVIDEND_CASH = 4
+    DIVIDEND_VOLUME = 5
+    DEDUCT_REWARD = 6
+    DEDUCT_REWARD_AND_DIVIDEND_VOLUME = 7
+    DEDUCT_REWARD_AND_DIVIDEND_CASH = 8
+    FORCE_PLUS = 9
+    FORCE_MINUS = 10
+
+
+class FOFStatementStatus(ReadableEnum):
+    """FOF资产状态"""
+    IN_INVESTOR = 1             # 投资者投入
+    OUT_INVESTOR = 2            # 投资者取出
+    IN_HEDGE = 3                # 底层资产卖出
+    OUT_HEDGE = 4               # 底层资产买入
+    IN_HEDGE_DIVIDEND = 5       # 底层资产分红
+    OUT_FOF_DIVIDEND = 6        # 产品分红
+    IN_INTEREST = 7             # 利息入账
+    OUT_MANAGEMENT = 8          # 管理费出账
+    OUT_CUSTODIAN = 9           # 托管费出账
+    OUT_ADMINISTRATIVE = 10     # 行政管理费出账
+    IN_OTHER_IN = 11            # 其他入账
+    OUT_OTHER_OUT = 12          # 其他出账
+
+
+class FOFTransitStatus(ReadableEnum):
+    """FOF在途资金状态"""
+    PENDING = 1
+    DONE = 2
+
+
+class FOFOtherRecordStatus(ReadableEnum):
+    """FOF其他记录状态"""
+    IN = 1
+    OUT = 2
+
