@@ -883,6 +883,7 @@ class FOFInfo(FOFBase):
     net_asset_value = Column(DOUBLE(asdecimal=False))  # 单位净值
     acc_unit_value = Column(DOUBLE(asdecimal=False))  # 累计净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
+    is_calculating = Column(BOOLEAN, default=False)       # 是否正在计算
 
 
 class FOFScaleAlteration(FOFBase):
@@ -1034,6 +1035,65 @@ class FOFEstimateFee(FOFBase):
     remark = Column(VARCHAR(255))                               # 备注
 
 
+class FOFRealAccountStatement(FOFBase):
+    """账户流水"""
+    __tablename__ = 'fof_account_statement_real'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                     # 产品ID
+    datetime = Column(DATETIME)                                     # 时间
+    trade_num = Column(CHAR(128))                                   # 流水编号
+    event_type = Column(Integer)                                    # 事件类型
+    amount = Column(DOUBLE(asdecimal=False))                        # 金额
+    remain_cash = Column(DOUBLE(asdecimal=False))                   # 账户余额
+    remark = Column(VARCHAR(255))                                   # 备注
+
+
+class FOFRealTransitMoney(FOFBase):
+    """在途资金"""
+    __tablename__ = 'fof_transit_money_real'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                             # 产品ID
+    fund_id = Column(CHAR(20))                                              # 基金ID
+    confirmed_datetime = Column(DATE)                                       # 确认时间
+    event_type = Column(Integer)                                            # 事件类型
+    amount = Column(DOUBLE(asdecimal=False))                                # 金额
+    transit_cash = Column(DOUBLE(asdecimal=False))                          # 在途资金总额
+    remark = Column(VARCHAR(255))                                           # 备注
+
+
+class FOFRealEstimateInterest(FOFBase):
+    """预估利息"""
+    __tablename__ = 'fof_estimate_interest_real'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                 # 产品ID
+    date = Column(DATE)                                         # 日期
+    remain_cash = Column(DOUBLE(asdecimal=False))               # 当日余额
+    interest = Column(DOUBLE(asdecimal=False))                  # 利息
+    remark = Column(VARCHAR(255))                               # 备注
+    total_interest = Column(DOUBLE(asdecimal=False))            # 总利息
+
+
+class FOFRealEstimateFee(FOFBase):
+    """预估计提费"""
+    __tablename__ = 'fof_estimate_fee_real'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    date = Column(DATE)  # 日期
+    pre_market_value = Column(DOUBLE(asdecimal=False))          # 前一日净资产总额
+    management_fee = Column(DOUBLE(asdecimal=False))            # 管理费
+    total_management_fee = Column(DOUBLE(asdecimal=False))      # 累计管理费
+    custodian_fee = Column(DOUBLE(asdecimal=False))             # 托管费
+    total_custodian_fee = Column(DOUBLE(asdecimal=False))       # 累计管理费
+    administrative_fee = Column(DOUBLE(asdecimal=False))        # 行政管理费
+    total_administrative_fee = Column(DOUBLE(asdecimal=False))  # 累计行政管理费
+    is_down = Column(BOOLEAN, default=False)                    # 是否结算
+    remark = Column(VARCHAR(255))                               # 备注
+
+
 class FOFOtherRecord(FOFBase):
     """其他记录"""
     __tablename__ = 'fof_other_record'
