@@ -242,8 +242,8 @@ class FundBacktestEngine(FundEngine):
         self._report_helper._plot_taa_saa(saa_mv, taa_mv, index_id)
         self._report_helper._index_pct_plot(index_id, saa_mv, taa_mv)
 
-    def get_last_position(self):
-        return self._report_helper.get_last_position()
+    def get_last_position(self,asset_target,result):
+        return self._report_helper.get_last_position(asset_target,result)
 
     def get_last_target_fund_allocation(self):
         return self._report_helper.get_last_target_fund_allocation(self._prep_target_fund_allocation.funds)
@@ -442,8 +442,8 @@ class BasicFundBacktestEngine(object):
         self._report_helper._plot_taa_saa(saa_mv, taa_mv, index_id)
         self._report_helper._index_pct_plot(index_id, saa_mv, taa_mv)
 
-    def get_last_position(self):
-        return self._report_helper.get_last_position()
+    def get_last_position(self,asset_target,result):
+        return self._report_helper.get_last_position(asset_target,result)
 
     def get_last_target_fund_allocation(self):
         return self._report_helper.get_last_target_fund_allocation(self._prep_target_fund_allocation.funds)
