@@ -216,8 +216,10 @@ class ReportHelper:
         w = self._calc_stat(self.fund_mv.copy())
         return w
 
-    def get_last_position(self):
+    def get_last_position(self,asset_target,result):
         last_date = list(self.fund_position_history.keys())[-1]
+        last_rebalance_dt = max(list(result['hold_years'].keys()))
+        last_rebalance_dt = pd.to_datetime(last_rebalance_dt).date()
         dic = self.fund_position_history[last_date]
         weight_dict = self.fund_weights_history[last_date]
         name_dict =  self.fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']
@@ -227,16 +229,93 @@ class ReportHelper:
         pos_df['desc_name'] = pos_df.index.map(lambda x : name_dict[x])
         pos_df.index.name = last_date
         pos_df = pos_df.sort_values('weight', ascending = False)
+        recent_index_price = self.index_price.loc[last_rebalance_dt:]
+        _index_price_recent_month_1 = recent_index_price / recent_index_price.iloc[0]
         dt = sorted(list(self.fund_score_dm.keys()))[-1]
+        last_month_start_day = last_date - datetime.timedelta(days=31)
+        last_month_start_day = self.dts[self.dts >= last_month_start_day].values[0]
+        _index_price_recent_month = self.index_price.loc[last_month_start_day:]
+        _index_ret_recent = _index_price_recent_month.iloc[-1] / _index_price_recent_month.iloc[0]
         fund_rank = []
+        fund_rank_pct = []
+        fund_vs_index_rate = {}
+        _price_rate_list = []
         for i in pos_df.itertuples():
             _score_dict = self.fund_score_dm[dt][i.index_id][self.score_select[i.index_id]]
             _score_list = sorted(_score_dict.items(), key=lambda x:x[1], reverse=True)
             _fund_list = [i[0] for i in _score_list]
             rank_i = _fund_list.index(i.Index) + 1 if i.Index in _fund_list else 10000
+            rank_pct = (_fund_list.index(i.Index) + 1) / len(_fund_list) if i.Index in _fund_list else 1
             fund_rank.append(rank_i)
+            fund_rank_pct.append(rank_pct)
+            _fund_nav_recent_month = self.fund_nav.loc[last_month_start_day:][_fund_list]
+            _fund_ret_recent = _fund_nav_recent_month.iloc[-1] / _fund_nav_recent_month.iloc[0]
+            r = np.mean([_fund_ret_recent >= _index_ret_recent[i.index_id]])
+            fund_vs_index_rate[i.index_id] = r
+            
+            _fund_nav_recent_month = self.fund_nav.loc[last_rebalance_dt:][[i.Index]]
+            _fund_nav_recent_month_1 = _fund_nav_recent_month.reindex(_index_price_recent_month_1.index.intersection(_fund_nav_recent_month.index))
+            _fund_nav_recent_month_1 = _fund_nav_recent_month_1 / _fund_nav_recent_month_1.iloc[0]
+            _fund_nav_recent_month_1 = _fund_nav_recent_month_1.div(_index_price_recent_month_1[i.index_id].values,axis=0)
+            for fund_id in _fund_nav_recent_month_1:
+                sr = _fund_nav_recent_month_1[fund_id]
+                mdd_part =  sr / sr.rolling(window=sr.shape[0], min_periods=1).max()
+                mdd = 1 - mdd_part.min()
+                mdd_date2 = mdd_part.idxmin()
+                mdd_date1 = sr[:mdd_date2].idxmax()
+                mdd_lens = (mdd_date2-mdd_date1).days
+                dic = {
+                    'fund_id':fund_id,
+                    'relative_mdd':mdd,
+                    'relative_mdd_day_length':mdd_lens
+                }
+                _price_rate_list.append(dic)
+            
         pos_df = pos_df.join(self.fund_info.set_index('fund_id')[['fund_manager']])
         pos_df.loc[:,'fund_rank'] = fund_rank
+        pos_df.loc[:,'fund_rank_pct'] = fund_rank_pct
+        #asset_target = self._prep_target_asset_allocation
+        asset_target = {k: round(v,2) for k,v in asset_target.__dict__.items()}
+        pos_df.index.name = 'fund_id'
+        pos_df = pos_df.reset_index()
+        cur_index_pos = pos_df[['index_id','weight']].groupby('index_id').sum().rename(columns={'weight':'cur_index_weight'})
+        pos_df = pos_df.set_index('index_id').join(cur_index_pos,on='index_id').reset_index()
+        pos_df.loc[:,'target_index_weight'] = pos_df.index_id.map(lambda x: asset_target[x])
+
+        index_cur_mdd_dic = 1 - recent_index_price.iloc[0] / recent_index_price.max()
+        pos_df.loc[:,'cur_index_mdd'] = pos_df.index_id.map(lambda x:index_cur_mdd_dic[x])
+        recent_fund_nav = self.fund_nav[pos_df.fund_id.tolist()].loc[last_rebalance_dt:]
+        fund_cur_mdd_dic = 1 - recent_fund_nav.iloc[0] / recent_fund_nav.max()
+        pos_df.loc[:,'cur_fund_mdd'] = pos_df.fund_id.map(lambda x:fund_cur_mdd_dic[x])
+        pos_df.loc[:,'fund_ex_index_ret_rate_recent_1m'] = pos_df.index_id.map(lambda x: fund_vs_index_rate[x])
+        relative_mdd_detail = pd.DataFrame(_price_rate_list).set_index('fund_id')
+        pos_df = pos_df.set_index('fund_id').join(relative_mdd_detail).reset_index()
+        pos_df['index_weight_diff'] = abs(pos_df['target_index_weight'] - pos_df['cur_index_weight'])
+        name_dic = {
+            'fund_id':'基金id',
+            'index_id':'指数id',
+            'weight':'基金权重',
+            'desc_name':'基金名称',
+            'fund_manager':'基金经理',
+            'fund_rank':'基金排名',
+            'fund_rank_pct':'基金排名百分比',
+            'cur_index_weight':'大类资产权重',
+            'target_index_weight':'大类资产目标权重',
+            'cur_index_mdd':'大类资产当前回撤',
+            'cur_fund_mdd':'基金资产当前回撤',
+            'fund_ex_index_ret_rate_recent_1m':'最近一月超越指数涨幅的基金数目比率',
+            'relative_mdd':'价格比最大回撤',
+            'relative_mdd_day_length':'价格比最大回撤持续自然日',
+            'index_weight_diff':'大类资产偏移权重',
+        }
+        pct_cols = ['weight','fund_rank_pct','cur_index_weight','target_index_weight','cur_index_mdd','cur_fund_mdd','fund_ex_index_ret_rate_recent_1m','relative_mdd','index_weight_diff']
+        for pct_col in pct_cols:
+            pos_df[pct_col] = pos_df[pct_col].map(lambda x:str(round(x*100,1))+'%')
+        df_cols_order = ['fund_id','index_id', 'weight', 'desc_name', 'fund_manager',
+                 'fund_rank', 'fund_rank_pct','cur_index_weight', 'target_index_weight','index_weight_diff',
+                 'cur_index_mdd', 'cur_fund_mdd', 'fund_ex_index_ret_rate_recent_1m','relative_mdd', 'relative_mdd_day_length'
+                ]
+        pos_df = pos_df[df_cols_order].rename(columns=name_dic)
         return pos_df
 
     def get_last_target_fund_allocation(self, target_fund):
