@@ -1384,7 +1384,7 @@ class ManagerIndex(Factor):
             df = mng_index.copy()
             df.columns = [f'{fund_type}_{i}' for i in df.columns]
             df = df / df.iloc[0]
-            df_part = (_exsited_factor[df.columns].iloc[-1] * df).iloc[1:]
+            df_part = (_exsited_factor[df.columns.intersection(_exsited_factor.columns)].iloc[-1] * df).iloc[1:]
             res_df.append(df_part)
         update_result = pd.concat(res_df,axis=1)
         mng_index = _exsited_factor.append(update_result)
@@ -1663,7 +1663,7 @@ class MngClAlphaBetaWeekly1Y(Factor):
 
     def __init__(self):
         super().__init__(f_name='MngClAlphaBetaWeekly1Y', f_type=FundFactorType.DERIVED, f_level='derived')
-        self._deps.add(ManagerIndexWeekly())
+        self._deps.add(ManagerIndexRetWeekly())
         self._deps.add(TradingDay())
         self._deps.add(IndexRetWeekly())
 
@@ -1705,7 +1705,7 @@ class MngClAlphaBetaWeekly1Y(Factor):
 
     def append_update(self):
         self._factor  = self.get()
-        mng_weekly_ret = ManagerIndexWeekly().get()
+        mng_weekly_ret = ManagerIndexRetWeekly().get()
         index_weekly_ret = IndexRetWeekly().get().rename(columns=Calculator.INDEX_DICT)[list(Calculator.INDEX_DICT.values())]
         last_date = self._factor.index[-1]
         td = index_weekly_ret.index
@@ -1723,7 +1723,7 @@ class MngClAlphaBetaWeekly1Y(Factor):
         return self.save()
 
     def calc(self, is_multi_cpu=False):
-        mng_weekly_ret = ManagerIndexWeekly().get()
+        mng_weekly_ret = ManagerIndexRetWeekly().get()
         index_weekly_ret = IndexRetWeekly().get().rename(columns=Calculator.INDEX_DICT)[list(Calculator.INDEX_DICT.values())]
         mng_list = mng_weekly_ret.columns.tolist()
         # calculate
@@ -1780,7 +1780,7 @@ class MngClAlphaBetaWeeklyHistory(Factor):
 
     def __init__(self):
         super().__init__(f_name='MngClAlphaBetaWeeklyHistory', f_type=FundFactorType.DERIVED, f_level='derived')
-        self._deps.add(ManagerIndexWeekly())
+        self._deps.add(ManagerIndexRetWeekly())
         self._deps.add(TradingDay())
         self._deps.add(IndexRetWeekly())
 
@@ -1822,7 +1822,7 @@ class MngClAlphaBetaWeeklyHistory(Factor):
 
     def append_update(self):
         self._factor  = self.get()
-        mng_weekly_ret = ManagerIndexWeekly().get()
+        mng_weekly_ret = ManagerIndexRetWeekly().get()
         index_weekly_ret = IndexRetWeekly().get().rename(columns=Calculator.INDEX_DICT)[list(Calculator.INDEX_DICT.values())]
         last_date = self._factor.index[-1]
         td = index_weekly_ret.index
@@ -1840,7 +1840,7 @@ class MngClAlphaBetaWeeklyHistory(Factor):
         return self.save()
 
     def calc(self, is_multi_cpu=False):
-        mng_weekly_ret = ManagerIndexWeekly().get()
+        mng_weekly_ret = ManagerIndexRetWeekly().get()
         index_weekly_ret = IndexRetWeekly().get().rename(columns=Calculator.INDEX_DICT)[list(Calculator.INDEX_DICT.values())]
         mng_list = mng_weekly_ret.columns.tolist()
         # calculate
