@@ -153,13 +153,45 @@ class CalculatorBase:
                        values: pd.core.series.Series,
                        frequency: str='3M'):
         assert frequency in ['1D','1W','2W','1M','3M','1Y'], 'frequency provided is not included, must in 1D 1W 2W 1M 3M 1Y'
+        if frequency == '1Y':
+            sr = pd.Series(values, index=dates).sort_index().dropna()
+            year_list = set(sorted([i.year for i in sr.index]))
+            _date = []
+            for y in year_list:
+                for m_d in [[12,31]]:
+                    m = m_d[0]
+                    d = m_d[1]
+                    dt = datetime.date(y,m,d)
+                    _date.append(dt)
+            sr = sr.reindex(sr.index.union(_date)).sort_index().ffill().bfill()
+            sr = sr.reindex([sr.index[0]] + _date).pct_change(1).dropna()
+            sr = sr[sr!=0]
+            df = pd.DataFrame(sr)
+            df.columns = ['ret']
+            return df.sort_index()
+        if frequency == '3M':
+            sr = pd.Series(values, index=dates).sort_index().dropna()
+            year_list = set(sorted([i.year for i in sr.index]))
+            _date = []
+            for y in year_list:
+                for m_d in [[3,31],[6,30],[9,30],[12,31]]:
+                    m = m_d[0]
+                    d = m_d[1]
+                    dt = datetime.date(y,m,d)
+                    _date.append(dt)
+            sr = sr.reindex(sr.index.union(_date)).sort_index().ffill().bfill()
+            sr = sr.reindex(_date).pct_change(1).dropna()
+            sr = sr[sr!=0]
+            df = pd.DataFrame(sr)
+            df.columns = ['ret']
+            return df.sort_index()
         sr = pd.Series(values, index=dates).sort_index().dropna()
         sr = sr.set_axis(pd.to_datetime(sr.index), inplace=False).resample(frequency,).last().dropna()
         df = pd.DataFrame(sr.pct_change(1).dropna())
         df.columns = ['ret']
         td = df.index
         df.index = [i.date() for i in td]
-        return df
+        return df.sort_index()
 
     @staticmethod
     def calc_recent_vol(dates:             pd.core.series.Series,
@@ -207,13 +239,65 @@ class CalculatorBase:
                        values: pd.core.series.Series,
                        frequency: str='3M'):
         assert frequency in ['1D','1W','2W','1M','3M','1Y'], 'frequency provided is not included, must in 1D 1W 2W 1M 3M 1Y'
-        sr = pd.Series(values, index=dates).sort_index().dropna()
-        sr = sr.set_axis(pd.to_datetime(sr.index), inplace=False).resample(frequency,).std(ddof=1).dropna()
-        df = pd.DataFrame(sr) * np.sqrt(CalculatorBase.TRADING_DAYS_PER_YEAR)
+        sr = pd.Series(values, index=dates).sort_index().pct_change(1).dropna()
+        if frequency == '1D':
+            roll_d = CalculatorBase.TRADING_DAYS_PER_YEAR
+        elif frequency == '1W':
+            roll_d = 5
+        elif frequency == '2W':
+            roll_d = 10
+        elif frequency == '1M':
+            roll_d = 20
+        elif frequency == '3M':
+            roll_d = 60
+        elif frequency == '1Y':
+            roll_d = CalculatorBase.TRADING_DAYS_PER_YEAR
+        if frequency == '1Y':
+            sr = pd.Series(values, index=dates).sort_index().dropna()
+            year_list = set(sorted([i.year for i in sr.index]))
+            _date = []
+            for y in year_list:
+                for m_d in [[12,31]]:
+                    m = m_d[0]
+                    d = m_d[1]
+                    dt = datetime.date(y,m,d)
+                    _date.append(dt)
+            sr = sr.reindex(sr.index.union(_date)).sort_index().ffill().pct_change(1)
+            sr = sr.rolling(window=roll_d).std(ddof=1) * np.sqrt(CalculatorBase.TRADING_DAYS_PER_YEAR)
+            sr = sr.reindex(_date).dropna()
+            sr = sr[sr!=0]
+            df = pd.DataFrame(sr)
+            df.columns = ['vol']
+            return df.sort_index()
+        if frequency == '3M':
+            sr = pd.Series(values, index=dates).sort_index().dropna()
+            year_list = set(sorted([i.year for i in sr.index]))
+            _date = []
+            for y in year_list:
+                for m_d in [[3,31],[6,30],[9,30],[12,31]]:
+                    m = m_d[0]
+                    d = m_d[1]
+                    dt = datetime.date(y,m,d)
+                    _date.append(dt)
+            sr = sr.reindex(sr.index.union(_date)).sort_index().ffill().pct_change(1)
+            sr = sr.rolling(window=roll_d).std(ddof=1) * np.sqrt(CalculatorBase.TRADING_DAYS_PER_YEAR)
+            sr = sr.reindex(_date).dropna()
+            sr = sr[sr!=0]
+            df = pd.DataFrame(sr)
+            df.columns = ['vol']
+            df = df.sort_index()
+            today = datetime.datetime.now().date()
+            this_year = today.year
+            year_list = np.array([datetime.date(this_year, m_d[0], m_d[1]) for m_d in [[3,31],[6,30],[9,30],[12,31]]])
+            next_report_date = year_list[year_list>today][0]
+            return df.loc[:next_report_date]
+        sr = sr.rolling(window=roll_d).std(ddof=1) * np.sqrt(CalculatorBase.TRADING_DAYS_PER_YEAR)
+        sr = sr.set_axis(pd.to_datetime(sr.index), inplace=False).resample(frequency).last().dropna()
+        df = pd.DataFrame(sr)
         df.columns = ['vol']
         td = df.index
         df.index = [i.date() for i in td]
-        return df
+        return df.sort_index()
 
     @staticmethod
     def get_fund_correlation_df(df: pd.DataFrame):
