@@ -40,12 +40,13 @@ class MailAttachmentRetriever:
                 if last_uid is None:
                     criterion = '(UNSEEN)'
                 else:
+                    last_uid = int(last_uid)
                     criterion = f'(TO "fof@puyuan.tech" UID {last_uid}:*)'
                     print(criterion)
                 typ, data = M.uid('search', None, criterion)
                 for uid in data[0].split():
                     # 上边的criterion不太好用 这里还是需要再过滤一下
-                    if last_uid is not None and uid <= last_uid:
+                    if last_uid is not None and int(uid) <= last_uid:
                         continue
                     # 邮件应该是按顺序过来的
                     # 遍历每一封邮件
@@ -59,7 +60,9 @@ class MailAttachmentRetriever:
                             if part.get('Content-Disposition') is not None:
                                 filename = part.get_filename()
                                 if filename is not None:
-                                    real_name = email.header.decode_header(filename)[0][0].decode(email.header.decode_header(filename)[0][1])
+                                    real_name = email.header.decode_header(filename)[0][0]
+                                    if isinstance(real_name, bytes):
+                                        real_name = real_name.decode(email.header.decode_header(filename)[0][1])
                                     if real_name.endswith('.xls') or real_name.endswith('xlsx'):
                                         # pandas可以直接读，但pd.read_excel()里传的参数可能是不一样的，所以这里还是先将内容写到文件里
                                         file_path = os.path.join(self._dump_dir, real_name)
